module cpu_X5 (
	pj_su,
	pj_boot8,
	pj_no_fpu,
	pj_irl,
	pj_nmi,
	pj_brk1_sync,
        pj_brk2_sync,
        pj_in_halt,
        pj_inst_complete,
        pj_halt,
        pj_resume,
	pj_standby_out,
	sm, 
	sin, 
	so, 
	pj_clk_out,
	clk, 
	clk_gate, 
	pj_reset_out,
	reset_l,
	pj_dcureq,
	pj_dcusize,
	pj_dcutype,
	pj_dcuaddr,
	pj_dataout,
	pj_dcuack,
	pj_icureq,
	pj_icusize,
	pj_icutype,
	pj_icuaddr,
	pj_icuack,
	pj_datain,
	pj_perf_sgnl,
	dc_test_err_l,
	dt_test_err_l,
	ic_test_err_l,
	it_test_err_l,
	bist_mode,
	bist_reset,
	test_mode
);

// Memory Interface Signals.
        output pj_su;

// Debug Interface Signals.
        output pj_brk1_sync;
        output pj_brk2_sync;
        output pj_in_halt;
        output pj_inst_complete;
        input pj_halt;
        input pj_resume;

// Processor Interface Signals.
        input pj_boot8;
        input pj_no_fpu;
        input [3:0] pj_irl;
        input pj_nmi;
        input sm;
        input sin;
        input reset_l;
        output pj_standby_out;
        output pj_reset_out;
        input clk;
        input clk_gate;
        output pj_clk_out;
        output so;

//	BIU signals...
	output pj_dcureq;
	output [1:0] pj_dcusize;
	output [2:0] pj_dcutype;
	output [31:0] pj_dcuaddr;
	output [31:0] pj_dataout;
	output pj_icureq;
	output [1:0] pj_icusize;
	output pj_icutype;
	output [31:0] pj_icuaddr;
	input [1:0] pj_dcuack;
	input [1:0] pj_icuack;
	input [31:0] pj_datain;

// 	These are performance counter connection ports
        output [5:0] pj_perf_sgnl;

//	These are test mode connection ports
	output dc_test_err_l;
	output dt_test_err_l;
	output ic_test_err_l;
	output it_test_err_l;
	input [1:0] bist_mode;
	input bist_reset;
	input test_mode;

//######################################################################
// instance cpu_N0

// Memory Interface Signals.
wire pj_su_N0;

// Debug Interface Signals.
wire pj_brk1_sync_N0;
wire pj_brk2_sync_N0;
wire pj_in_halt_N0;
wire pj_inst_complete_N0;
wire pj_halt_N0 = pj_halt;
wire pj_resume_N0 = pj_resume;

// Processor Interface Signals.
wire pj_boot8_N0 = pj_boot8;
wire pj_no_fpu_N0 = pj_no_fpu;
wire [3:0] pj_irl_N0 = pj_irl;
wire pj_nmi_N0 = pj_nmi;
wire pj_standby_out_N0;
wire pj_reset_out_N0;
wire clk_gate_N0 = clk_gate;
wire pj_clk_out_N0;
wire so_N0;

//	BIU signals...
wire pj_dcureq_N0;
wire [1:0] pj_dcusize_N0;
wire [2:0] pj_dcutype_N0;
wire [31:0] pj_dcuaddr_N0;
wire [31:0] pj_dataout_N0;
wire pj_icureq_N0;
wire [1:0] pj_icusize_N0;
wire pj_icutype_N0;
wire [31:0] pj_icuaddr_N0;
wire [1:0] pj_dcuack_N0 = pj_dcuack;
wire [1:0] pj_icuack_N0 = pj_icuack;
wire [31:0] pj_datain_N0 = pj_datain;

// 	These are performance counter connection ports
wire [5:0] pj_perf_sgnl_N0;

//	These are test mode connection ports
wire dc_test_err_l_N0;
wire dt_test_err_l_N0;
wire ic_test_err_l_N0;
wire it_test_err_l_N0;
wire [1:0] bist_mode_N0 = bist_mode;
wire bist_reset_N0 = bist_reset;
wire test_mode_N0 = test_mode;

cpu_N0 cpu_N0 (
	pj_su_N0,
	pj_boot8_N0,
	pj_no_fpu_N0,
	pj_irl_N0,
	pj_nmi_N0,
	pj_brk1_sync_N0,
        pj_brk2_sync_N0,
        pj_in_halt_N0,
        pj_inst_complete_N0,
        pj_halt_N0,
        pj_resume_N0,
	pj_standby_out_N0,
	sm, 
	sin, 
	so_N0, 
	pj_clk_out_N0,
	clk, 
	clk_gate_N0, 
	pj_reset_out_N0,
	reset_l,
	pj_dcureq_N0,
	pj_dcusize_N0,
	pj_dcutype_N0,
	pj_dcuaddr_N0,
	pj_dataout_N0,
	pj_dcuack_N0,
	pj_icureq_N0,
	pj_icusize_N0,
	pj_icutype_N0,
	pj_icuaddr_N0,
	pj_icuack_N0,
	pj_datain_N0,
	pj_perf_sgnl_N0,
	dc_test_err_l_N0,
	dt_test_err_l_N0,
	ic_test_err_l_N0,
	it_test_err_l_N0,
	bist_mode_N0,
	bist_reset_N0,
	test_mode_N0
);

//######################################################################
// instance cpu_N1

// Memory Interface Signals.
wire pj_su_N1;

// Debug Interface Signals.
wire pj_brk1_sync_N1;
wire pj_brk2_sync_N1;
wire pj_in_halt_N1;
wire pj_inst_complete_N1;
wire pj_halt_N1 = pj_su_N0 ^ pj_icureq_N0;
wire pj_resume_N1 = pj_brk1_sync_N0 ^ pj_icutype_N0;

// Processor Interface Signals.
wire pj_boot8_N1 = pj_brk2_sync_N0 ^ pj_standby_out_N0;
wire pj_no_fpu_N1 = pj_in_halt_N0;
wire [3:0] pj_irl_N1 = pj_perf_sgnl_N0[3:0] ^ {pj_reset_out_N0,pj_dcutype_N0};
wire pj_nmi_N1 = pj_inst_complete_N0 ^ pj_dcureq_N0;
wire pj_standby_out_N1;
wire pj_reset_out_N1;
wire clk_gate_N1 = pj_clk_out_N0;
wire pj_clk_out_N1;
wire so_N1;

//	BIU signals...
wire pj_dcureq_N1;
wire [1:0] pj_dcusize_N1;
wire [2:0] pj_dcutype_N1;
wire [31:0] pj_dcuaddr_N1;
wire [31:0] pj_dataout_N1;
wire pj_icureq_N1;
wire [1:0] pj_icusize_N1;
wire pj_icutype_N1;
wire [31:0] pj_icuaddr_N1;
wire [1:0] pj_dcuack_N1 = pj_dcusize_N0;
wire [1:0] pj_icuack_N1 = pj_icusize_N0;
wire [31:0] pj_datain_N1 = pj_dcuaddr_N0 ^ pj_dataout_N0 ^ pj_icuaddr_N0;

// 	These are performance counter connection ports
wire [5:0] pj_perf_sgnl_N1;

//	These are test mode connection ports
wire dc_test_err_l_N1;
wire dt_test_err_l_N1;
wire ic_test_err_l_N1;
wire it_test_err_l_N1;
wire [1:0] bist_mode_N1 = pj_perf_sgnl_N0[5:4];
wire bist_reset_N1 = ic_test_err_l_N0 ^ dc_test_err_l_N0;
wire test_mode_N1 = it_test_err_l_N0 ^ dt_test_err_l_N0;

cpu_N1 cpu_N1 (
	pj_su_N1,
	pj_boot8_N1,
	pj_no_fpu_N1,
	pj_irl_N1,
	pj_nmi_N1,
	pj_brk1_sync_N1,
        pj_brk2_sync_N1,
        pj_in_halt_N1,
        pj_inst_complete_N1,
        pj_halt_N1,
        pj_resume_N1,
	pj_standby_out_N1,
	sm, 
	sin, 
	so_N1, 
	pj_clk_out_N1,
	clk, 
	clk_gate_N1, 
	pj_reset_out_N1,
	reset_l,
	pj_dcureq_N1,
	pj_dcusize_N1,
	pj_dcutype_N1,
	pj_dcuaddr_N1,
	pj_dataout_N1,
	pj_dcuack_N1,
	pj_icureq_N1,
	pj_icusize_N1,
	pj_icutype_N1,
	pj_icuaddr_N1,
	pj_icuack_N1,
	pj_datain_N1,
	pj_perf_sgnl_N1,
	dc_test_err_l_N1,
	dt_test_err_l_N1,
	ic_test_err_l_N1,
	it_test_err_l_N1,
	bist_mode_N1,
	bist_reset_N1,
	test_mode_N1
);

//######################################################################
// instance cpu_N2

// Memory Interface Signals.
wire pj_su_N2;

// Debug Interface Signals.
wire pj_brk1_sync_N2;
wire pj_brk2_sync_N2;
wire pj_in_halt_N2;
wire pj_inst_complete_N2;
wire pj_halt_N2 = pj_su_N1 ^ pj_icureq_N1;
wire pj_resume_N2 = pj_brk1_sync_N1 ^ pj_icutype_N1;

// Processor Interface Signals.
wire pj_boot8_N2 = pj_brk2_sync_N1 ^ pj_standby_out_N1;
wire pj_no_fpu_N2 = pj_in_halt_N1;
wire [3:0] pj_irl_N2 = pj_perf_sgnl_N1[3:0] ^ {pj_reset_out_N1,pj_dcutype_N1};
wire pj_nmi_N2 = pj_inst_complete_N1 ^ pj_dcureq_N1;
wire pj_standby_out_N2;
wire pj_reset_out_N2;
wire clk_gate_N2 = pj_clk_out_N1;
wire pj_clk_out_N2;
wire so_N2;

//	BIU signals...
wire pj_dcureq_N2;
wire [1:0] pj_dcusize_N2;
wire [2:0] pj_dcutype_N2;
wire [31:0] pj_dcuaddr_N2;
wire [31:0] pj_dataout_N2;
wire pj_icureq_N2;
wire [1:0] pj_icusize_N2;
wire pj_icutype_N2;
wire [31:0] pj_icuaddr_N2;
wire [1:0] pj_dcuack_N2 = pj_dcusize_N1;
wire [1:0] pj_icuack_N2 = pj_icusize_N1;
wire [31:0] pj_datain_N2 = pj_dcuaddr_N1 ^ pj_dataout_N1 ^ pj_icuaddr_N1;

// 	These are performance counter connection ports
wire [5:0] pj_perf_sgnl_N2;

//	These are test mode connection ports
wire dc_test_err_l_N2;
wire dt_test_err_l_N2;
wire ic_test_err_l_N2;
wire it_test_err_l_N2;
wire [1:0] bist_mode_N2 = pj_perf_sgnl_N1[5:4];
wire bist_reset_N2 = ic_test_err_l_N1 ^ dc_test_err_l_N1;
wire test_mode_N2 = it_test_err_l_N1 ^ dt_test_err_l_N1;

cpu_N2 cpu_N2 (
	pj_su_N2,
	pj_boot8_N2,
	pj_no_fpu_N2,
	pj_irl_N2,
	pj_nmi_N2,
	pj_brk1_sync_N2,
        pj_brk2_sync_N2,
        pj_in_halt_N2,
        pj_inst_complete_N2,
        pj_halt_N2,
        pj_resume_N2,
	pj_standby_out_N2,
	sm, 
	sin, 
	so_N2, 
	pj_clk_out_N2,
	clk, 
	clk_gate_N2, 
	pj_reset_out_N2,
	reset_l,
	pj_dcureq_N2,
	pj_dcusize_N2,
	pj_dcutype_N2,
	pj_dcuaddr_N2,
	pj_dataout_N2,
	pj_dcuack_N2,
	pj_icureq_N2,
	pj_icusize_N2,
	pj_icutype_N2,
	pj_icuaddr_N2,
	pj_icuack_N2,
	pj_datain_N2,
	pj_perf_sgnl_N2,
	dc_test_err_l_N2,
	dt_test_err_l_N2,
	ic_test_err_l_N2,
	it_test_err_l_N2,
	bist_mode_N2,
	bist_reset_N2,
	test_mode_N2
);

//######################################################################
// instance cpu_N3

// Memory Interface Signals.
wire pj_su_N3;

// Debug Interface Signals.
wire pj_brk1_sync_N3;
wire pj_brk2_sync_N3;
wire pj_in_halt_N3;
wire pj_inst_complete_N3;
wire pj_halt_N3 = pj_su_N2 ^ pj_icureq_N2;
wire pj_resume_N3 = pj_brk1_sync_N2 ^ pj_icutype_N2;

// Processor Interface Signals.
wire pj_boot8_N3 = pj_brk2_sync_N2 ^ pj_standby_out_N2;
wire pj_no_fpu_N3 = pj_in_halt_N2;
wire [3:0] pj_irl_N3 = pj_perf_sgnl_N2[3:0] ^ {pj_reset_out_N2,pj_dcutype_N2};
wire pj_nmi_N3 = pj_inst_complete_N2 ^ pj_dcureq_N2;
wire pj_standby_out_N3;
wire pj_reset_out_N3;
wire clk_gate_N3 = pj_clk_out_N2;
wire pj_clk_out_N3;
wire so_N3;

//	BIU signals...
wire pj_dcureq_N3;
wire [1:0] pj_dcusize_N3;
wire [2:0] pj_dcutype_N3;
wire [31:0] pj_dcuaddr_N3;
wire [31:0] pj_dataout_N3;
wire pj_icureq_N3;
wire [1:0] pj_icusize_N3;
wire pj_icutype_N3;
wire [31:0] pj_icuaddr_N3;
wire [1:0] pj_dcuack_N3 = pj_dcusize_N2;
wire [1:0] pj_icuack_N3 = pj_icusize_N2;
wire [31:0] pj_datain_N3 = pj_dcuaddr_N2 ^ pj_dataout_N2 ^ pj_icuaddr_N2;

// 	These are performance counter connection ports
wire [5:0] pj_perf_sgnl_N3;

//	These are test mode connection ports
wire dc_test_err_l_N3;
wire dt_test_err_l_N3;
wire ic_test_err_l_N3;
wire it_test_err_l_N3;
wire [1:0] bist_mode_N3 = pj_perf_sgnl_N2[5:4];
wire bist_reset_N3 = ic_test_err_l_N2 ^ dc_test_err_l_N2;
wire test_mode_N3 = it_test_err_l_N2 ^ dt_test_err_l_N2;

cpu_N3 cpu_N3 (
	pj_su_N3,
	pj_boot8_N3,
	pj_no_fpu_N3,
	pj_irl_N3,
	pj_nmi_N3,
	pj_brk1_sync_N3,
        pj_brk2_sync_N3,
        pj_in_halt_N3,
        pj_inst_complete_N3,
        pj_halt_N3,
        pj_resume_N3,
	pj_standby_out_N3,
	sm, 
	sin, 
	so_N3, 
	pj_clk_out_N3,
	clk, 
	clk_gate_N3, 
	pj_reset_out_N3,
	reset_l,
	pj_dcureq_N3,
	pj_dcusize_N3,
	pj_dcutype_N3,
	pj_dcuaddr_N3,
	pj_dataout_N3,
	pj_dcuack_N3,
	pj_icureq_N3,
	pj_icusize_N3,
	pj_icutype_N3,
	pj_icuaddr_N3,
	pj_icuack_N3,
	pj_datain_N3,
	pj_perf_sgnl_N3,
	dc_test_err_l_N3,
	dt_test_err_l_N3,
	ic_test_err_l_N3,
	it_test_err_l_N3,
	bist_mode_N3,
	bist_reset_N3,
	test_mode_N3
);

//######################################################################
// instance cpu_N4

// Memory Interface Signals.
wire pj_su_N4;

// Debug Interface Signals.
wire pj_brk1_sync_N4;
wire pj_brk2_sync_N4;
wire pj_in_halt_N4;
wire pj_inst_complete_N4;
wire pj_halt_N4 = pj_su_N3 ^ pj_icureq_N3;
wire pj_resume_N4 = pj_brk1_sync_N3 ^ pj_icutype_N3;

// Processor Interface Signals.
wire pj_boot8_N4 = pj_brk2_sync_N3 ^ pj_standby_out_N3;
wire pj_no_fpu_N4 = pj_in_halt_N3;
wire [3:0] pj_irl_N4 = pj_perf_sgnl_N3[3:0] ^ {pj_reset_out_N3,pj_dcutype_N3};
wire pj_nmi_N4 = pj_inst_complete_N3 ^ pj_dcureq_N3;
wire pj_standby_out_N4;
wire pj_reset_out_N4;
wire clk_gate_N4 = pj_clk_out_N3;
wire pj_clk_out_N4;
wire so_N4;

//	BIU signals...
wire pj_dcureq_N4;
wire [1:0] pj_dcusize_N4;
wire [2:0] pj_dcutype_N4;
wire [31:0] pj_dcuaddr_N4;
wire [31:0] pj_dataout_N4;
wire pj_icureq_N4;
wire [1:0] pj_icusize_N4;
wire pj_icutype_N4;
wire [31:0] pj_icuaddr_N4;
wire [1:0] pj_dcuack_N4 = pj_dcusize_N3;
wire [1:0] pj_icuack_N4 = pj_icusize_N3;
wire [31:0] pj_datain_N4 = pj_dcuaddr_N3 ^ pj_dataout_N3 ^ pj_icuaddr_N3;

// 	These are performance counter connection ports
wire [5:0] pj_perf_sgnl_N4;

//	These are test mode connection ports
wire dc_test_err_l_N4;
wire dt_test_err_l_N4;
wire ic_test_err_l_N4;
wire it_test_err_l_N4;
wire [1:0] bist_mode_N4 = pj_perf_sgnl_N3[5:4];
wire bist_reset_N4 = ic_test_err_l_N3 ^ dc_test_err_l_N3;
wire test_mode_N4 = it_test_err_l_N3 ^ dt_test_err_l_N3;

cpu_N4 cpu_N4 (
	pj_su_N4,
	pj_boot8_N4,
	pj_no_fpu_N4,
	pj_irl_N4,
	pj_nmi_N4,
	pj_brk1_sync_N4,
        pj_brk2_sync_N4,
        pj_in_halt_N4,
        pj_inst_complete_N4,
        pj_halt_N4,
        pj_resume_N4,
	pj_standby_out_N4,
	sm, 
	sin, 
	so_N4, 
	pj_clk_out_N4,
	clk, 
	clk_gate_N4, 
	pj_reset_out_N4,
	reset_l,
	pj_dcureq_N4,
	pj_dcusize_N4,
	pj_dcutype_N4,
	pj_dcuaddr_N4,
	pj_dataout_N4,
	pj_dcuack_N4,
	pj_icureq_N4,
	pj_icusize_N4,
	pj_icutype_N4,
	pj_icuaddr_N4,
	pj_icuack_N4,
	pj_datain_N4,
	pj_perf_sgnl_N4,
	dc_test_err_l_N4,
	dt_test_err_l_N4,
	ic_test_err_l_N4,
	it_test_err_l_N4,
	bist_mode_N4,
	bist_reset_N4,
	test_mode_N4
);

//######################################################################
// top-level outputs

// Memory Interface Signals.
assign pj_su = pj_su_N4;

// Debug Interface Signals.
assign pj_brk1_sync = pj_brk1_sync_N4;
assign pj_brk2_sync = pj_brk2_sync_N4;
assign pj_in_halt = pj_in_halt_N4;
assign pj_inst_complete = pj_inst_complete_N4;

// Processor Interface Signals.
assign pj_standby_out = pj_standby_out_N4;
assign pj_reset_out = pj_reset_out_N4;
assign pj_clk_out = pj_clk_out_N4;
assign so = so_N4;

//	BIU signals...
assign pj_dcureq = pj_dcureq_N4;
assign pj_dcusize = pj_dcusize_N4;
assign pj_dcutype = pj_dcutype_N4;
assign pj_dcuaddr = pj_dcuaddr_N4;
assign pj_dataout = pj_dataout_N4;
assign pj_icureq = pj_icureq_N4;
assign pj_icusize = pj_icusize_N4;
assign pj_icutype = pj_icutype_N4;
assign pj_icuaddr = pj_icuaddr_N4;

// 	These are performance counter connection ports
assign pj_perf_sgnl = pj_perf_sgnl_N4;

//	These are test mode connection ports
assign dc_test_err_l = dc_test_err_l_N4;
assign dt_test_err_l = dt_test_err_l_N4;
assign ic_test_err_l = ic_test_err_l_N4;
assign it_test_err_l = it_test_err_l_N4;

endmodule
